=== modified file 'lib/lp/soyuz/interfaces/distributionjob.py'
--- lib/lp/soyuz/interfaces/distributionjob.py	2011-07-22 09:01:03 +0000
+++ lib/lp/soyuz/interfaces/distributionjob.py	2011-07-22 11:12:23 +0000
@@ -138,18 +138,13 @@
         # XXX JeroenVermeulen 2011-05-26 bug=758906: Make parent_series
         # mandatory as part of multi-parent support.
 
-    def massCreateForSeries(derived_series, parent_series, archive,
-                            names=None):
-        """Create jobs for all the publications inside the given archive.
+    def massCreateForSeries(derived_series, parent_series):
+        """Create jobs for all the publications inside the given distroseries.
 
         :param derived_series: A `DistroSeries` that is assumed to be
             derived from `parent_series`.
         :param parent_series: The parent `DistroSeries`.
-        :param archive: The `IArchive` where the publications to be
-            considered are.
-        :param names: An optinal list of source package names to limit
-            the jobs to be created. None means create jobs for all the
-            publications in the archive.
+
         :return: An iterable of `DistroSeriesDifferenceJob` ids. We don't
             return the Job themselves for performance reason.
         """

=== modified file 'lib/lp/soyuz/interfaces/publishing.py'
--- lib/lp/soyuz/interfaces/publishing.py	2011-07-22 09:01:03 +0000
+++ lib/lp/soyuz/interfaces/publishing.py	2011-07-22 11:12:23 +0000
@@ -949,7 +949,8 @@
         """
 
     def newSourcePublication(archive, sourcepackagerelease, distroseries,
-                             component, section, pocket, ancestor):
+                             component, section, pocket, ancestor,
+                             create_dsd_job=True):
         """Create a new `SourcePackagePublishingHistory`.
 
         :param archive: An `IArchive`
@@ -960,6 +961,8 @@
         :param pocket: A `PackagePublishingPocket`
         :param ancestor: A `ISourcePackagePublishingHistory` for the previous
             version of this publishing record
+        :param create_dsd_job: A boolean indicating whether or not a dsd job
+             should be created for the new source publication.
 
         datecreated will be UTC_NOW.
         status will be PackagePublishingStatus.PENDING

=== modified file 'lib/lp/soyuz/model/distroseriesdifferencejob.py'
--- lib/lp/soyuz/model/distroseriesdifferencejob.py	2011-07-22 09:01:03 +0000
+++ lib/lp/soyuz/model/distroseriesdifferencejob.py	2011-07-22 11:12:23 +0000
@@ -83,8 +83,7 @@
     return DistroSeriesDifferenceJob(job)
 
 
-def create_multiple_jobs(derived_series, parent_series, archive,
-                         names=None):
+def create_multiple_jobs(derived_series, parent_series):
     """Create a `DistroSeriesDifferenceJob` for all the source packages in
     archive (optionally limited to the sourcepackagenames passed).
 
@@ -93,18 +92,7 @@
     :param parent_series: A `DistroSeries` that is a parent of
         `derived_series`.
     :param archive: A `IArchive` where to find the source packages.
-    :param names: An optinal list of source package names to limit
-        the jobs to be created. None means create jobs for all the
-        publications in the archive.
     """
-    names_filter = []
-    if names is not None:
-        names_filter = (
-            SourcePackagePublishingHistory.sourcepackagerelease ==
-                SourcePackageRelease.id,
-            SourcePackageRelease.sourcepackagename ==
-                SourcePackageName.id,
-            SourcePackageName.name.is_in(names))
     store = IStore(SourcePackageRelease)
     source_package_releases = store.find(
         SourcePackageRelease,
@@ -112,10 +100,8 @@
             SourcePackagePublishingHistory.sourcepackagerelease ==
                 SourcePackageRelease.id,
             SourcePackagePublishingHistory.distroseries == derived_series.id,
-            SourcePackagePublishingHistory.archive == archive.id,
             SourcePackagePublishingHistory.status.is_in(
-                active_publishing_status)),
-            *names_filter)
+                active_publishing_status)))
     nb_jobs = source_package_releases.count()
     sourcepackagenames = source_package_releases.values(
         SourcePackageRelease.sourcepackagenameID)
@@ -245,11 +231,11 @@
         return jobs
 
     @classmethod
-    def massCreateForSeries(cls, derived_series, parent_series, archive, names=None):
+    def massCreateForSeries(cls, derived_series, parent_series):
         """See `IDistroSeriesDifferenceJobSource`."""
         if not getFeatureFlag(FEATURE_FLAG_ENABLE_MODULE):
             return
-        create_multiple_jobs(derived_series, parent_series, archive, names)
+        create_multiple_jobs(derived_series, parent_series)
 
     @classmethod
     def getPendingJobsForDifferences(cls, derived_series,

=== modified file 'lib/lp/soyuz/model/publishing.py'
--- lib/lp/soyuz/model/publishing.py	2011-07-22 09:01:03 +0000
+++ lib/lp/soyuz/model/publishing.py	2011-07-22 11:12:23 +0000
@@ -802,7 +802,8 @@
             section=new_section,
             archive=current.archive)
 
-    def copyTo(self, distroseries, pocket, archive, override=None):
+    def copyTo(self, distroseries, pocket, archive, override=None,
+               create_dsd_job=True):
         """See `ISourcePackagePublishingHistory`."""
         component = self.component
         section = self.section
@@ -818,7 +819,8 @@
             component,
             section,
             pocket,
-            ancestor=None)
+            ancestor=None,
+            create_dsd_job=create_dsd_job)
 
     def getStatusSummaryForBuilds(self):
         """See `ISourcePackagePublishingHistory`."""
@@ -1468,7 +1470,7 @@
 
     def newSourcePublication(self, archive, sourcepackagerelease,
                              distroseries, component, section, pocket,
-                             ancestor=None):
+                             ancestor=None, create_dsd_job=True):
         """See `IPublishingSet`."""
         # Avoid circular import.
         from lp.registry.model.distributionsourcepackage import (
@@ -1486,11 +1488,12 @@
             ancestor=ancestor)
         DistributionSourcePackage.ensure(pub)
 
-        if archive == distroseries.main_archive:
-            dsd_job_source = getUtility(IDistroSeriesDifferenceJobSource)
-            dsd_job_source.createForPackagePublication(
-                distroseries, sourcepackagerelease.sourcepackagename,
-                pocket)
+        if create_dsd_job:
+            if archive == distroseries.main_archive:
+                dsd_job_source = getUtility(IDistroSeriesDifferenceJobSource)
+                dsd_job_source.createForPackagePublication(
+                    distroseries, sourcepackagerelease.sourcepackagename,
+                    pocket)
         return pub
 
     def getBuildsForSourceIds(

=== modified file 'lib/lp/soyuz/scripts/initialize_distroseries.py'
--- lib/lp/soyuz/scripts/initialize_distroseries.py	2011-07-22 09:01:03 +0000
+++ lib/lp/soyuz/scripts/initialize_distroseries.py	2011-07-22 11:12:23 +0000
@@ -214,6 +214,7 @@
         self._copy_architectures()
         self._copy_packages()
         self._copy_packagesets()
+        self._create_dsds()
         self._set_initialized()
         transaction.commit()
 
@@ -253,7 +254,7 @@
                 self.distroseries.previous_series)]
         return set(previous_series_parents) == set(self.parents)
 
-    def _create_dsds(self, archive, names=None):
+    def _create_dsds(self):
         if not self.first_derivation:
             if (self._has_same_parents_as_previous_series() and
                 not self.packagesets):
@@ -267,10 +268,10 @@
                 # previous_series's parents) or a selection only of the
                 # packagesets is being copied so we have to recompute
                 # the DSDs by creating DSD Jobs.
-                self._create_dsd_jobs(archive, names)
+                self._create_dsd_jobs()
         else:
             # If this is the first derivation, create the DSD Jobs.
-            self._create_dsd_jobs(archive, names)
+            self._create_dsd_jobs()
 
     def _copy_dsds_from_previous_series(self):
         self._store.execute("""
@@ -290,11 +291,10 @@
                 self.distroseries.id,
                 self.distroseries.previous_series.id))
 
-    def _create_dsd_jobs(self, archive, names):
+    def _create_dsd_jobs(self):
         job_source = getUtility(IDistroSeriesDifferenceJobSource)
         for parent in self.parents:
-            job_source.massCreateForSeries(
-                self.distroseries, parent, archive, names)
+            job_source.massCreateForSeries(self.distroseries, parent)
 
     def _copy_configuration(self):
         self.distroseries.backports_not_automatic = any(
@@ -423,10 +423,6 @@
                     getUtility(IPackageCloner).clonePackages(
                         origin, destination, distroarchseries_list,
                         proc_families, spns, self.rebuild)
-                    if spns:
-                        self._create_dsds(target_archive, names=spns)
-                    else:
-                        self._create_dsds(target_archive)
                 else:
                     # There is only one available pocket in an unreleased
                     # series.
@@ -442,11 +438,10 @@
                             sources, target_archive, self.distroseries,
                             pocket, include_binaries=not self.rebuild,
                             check_permissions=False, strict_binaries=False,
-                            close_bugs=False)
+                            close_bugs=False, create_dsd_job=False)
                         if self.rebuild:
                             for pubrec in sources_published:
                                 pubrec.createMissingBuilds()
-
                     except CannotCopy, error:
                         raise InitializationError(error)
 

=== modified file 'lib/lp/soyuz/scripts/packagecopier.py'
--- lib/lp/soyuz/scripts/packagecopier.py	2011-07-22 09:01:03 +0000
+++ lib/lp/soyuz/scripts/packagecopier.py	2011-07-22 11:12:23 +0000
@@ -525,7 +525,7 @@
 def do_copy(sources, archive, series, pocket, include_binaries=False,
             allow_delayed_copies=True, person=None, check_permissions=True,
             overrides=None, send_email=False, strict_binaries=True,
-            close_bugs=True):
+            close_bugs=True, create_dsd_job=True):
     """Perform the complete copy of the given sources incrementally.
 
     Verifies if each copy can be performed using `CopyChecker` and
@@ -561,6 +561,8 @@
         to True will make the copy fail if binaries cannot be also copied.
     :param close_bugs: A boolean indicating whether or not bugs on the
         copied publications should be closed.
+    :param create_dsd_job: A boolean indicating whether or not a dsd job
+         should be created for the new source publication.
 
 
     :raise CannotCopy when one or more copies were not allowed. The error
@@ -608,7 +610,8 @@
                 override = overrides[overrides_index]
             sub_copies = _do_direct_copy(
                 source, archive, destination_series, pocket,
-                include_binaries, override, close_bugs=close_bugs)
+                include_binaries, override, close_bugs=close_bugs,
+                create_dsd_job=create_dsd_job)
             if send_email:
                 notify(
                     person, source.sourcepackagerelease, [], [], archive,
@@ -622,7 +625,7 @@
 
 
 def _do_direct_copy(source, archive, series, pocket, include_binaries,
-                    override=None, close_bugs=True):
+                    override=None, close_bugs=True, create_dsd_job=True):
     """Copy publishing records to another location.
 
     Copy each item of the given list of `SourcePackagePublishingHistory`
@@ -643,6 +646,8 @@
     :param override: An `IOverride` as per do_copy().
     :param close_bugs: A boolean indicating whether or not bugs on the
         copied publication should be closed.
+    :param create_dsd_job: A boolean indicating whether or not a dsd job
+         should be created for the new source publication.
 
     :return: a list of `ISourcePackagePublishingHistory` and
         `BinaryPackagePublishingHistory` corresponding to the copied
@@ -672,7 +677,7 @@
                 "More than one override encountered, something is wrong.")
             override = overrides[0]
         source_copy = source.copyTo(
-            series, pocket, archive, override)
+            series, pocket, archive, override, create_dsd_job=create_dsd_job)
         if close_bugs:
             close_bugs_for_sourcepublication(source_copy)
         copies.append(source_copy)

=== modified file 'lib/lp/soyuz/scripts/tests/test_initialize_distroseries.py'
--- lib/lp/soyuz/scripts/tests/test_initialize_distroseries.py	2011-07-22 09:01:03 +0000
+++ lib/lp/soyuz/scripts/tests/test_initialize_distroseries.py	2011-07-22 11:12:23 +0000
@@ -44,7 +44,6 @@
     InitializeDistroSeries,
     )
 from lp.testing import TestCaseWithFactory
-from lp.testing.fakemethod import FakeMethod
 from lp.soyuz.model.distroseriesdifferencejob import (
     FEATURE_FLAG_ENABLE_MODULE,
     )
@@ -52,6 +51,7 @@
     find_waiting_jobs
     )
 
+
 class InitializationHelperTestCase(TestCaseWithFactory):
     # Helper class to:
     # - setup/populate parents with packages;
@@ -949,6 +949,17 @@
                 find_waiting_jobs(
                     series, sourcepackagename, parent_series)))
 
+    def test_initialization_first_deriv_create_dsdjs(self):
+        # A first initialization of a series creates the creation
+        # of the DSDJs with all the parents.
+        parent1, unused = self.setupParent(packages={u'p1': u'1.2'})
+        parent2, unused = self.setupParent(packages={u'p2': u'1.5'})
+        self.useFixture(FeatureFixture({FEATURE_FLAG_ENABLE_MODULE: 'on'}))
+        child = self._fullInitialize([parent1, parent2])
+
+        self.assertWaitingJobExists(child, 'p1', parent1)
+        self.assertWaitingJobExists(child, 'p2', parent2)
+
     def test_initialization_post_first_deriv_create_dsdjs(self):
         # Post-first initialization of a series with different parents
         # than those of the previous_series creates the DSDJs to
@@ -959,7 +970,7 @@
             previous_parents=[prev_parent1, prev_parent2])
         parent3, unused = self.setupParent(
             packages={u'p2': u'2.5', u'p3': u'1.1'})
-        self.useFixture(FeatureFixture({FEATURE_FLAG_ENABLE_MODULE:'on'}))
+        self.useFixture(FeatureFixture({FEATURE_FLAG_ENABLE_MODULE: 'on'}))
         self._fullInitialize(
             [prev_parent1, prev_parent2, parent3], child=child)
 
@@ -970,8 +981,8 @@
 
     def test_initialization_compute_dsds_specific_packagesets(self):
         # Post-first initialization of a series with specific
-        # packagesets creates the DSDJs.
-        self.useFixture(FeatureFixture({FEATURE_FLAG_ENABLE_MODULE:'on'}))
+        # packagesets creates the DSDJs for the packages inside these
+        # packagesets.
         prev_parent1, unused = self.setupParent(
             packages={u'p1': u'1.2', u'p11': u'3.1'})
         prev_parent2, unused = self.setupParent(packages={u'p2': u'1.5'})
@@ -983,6 +994,7 @@
         test1.addSources('p1')
         parent3, unused = self.setupParent(
             packages={u'p1': u'2.5', u'p3': u'4.4'})
+        self.useFixture(FeatureFixture({FEATURE_FLAG_ENABLE_MODULE: 'on'}))
         self._fullInitialize(
             [prev_parent1, prev_parent2, parent3], child=child,
             packagesets=(str(test1.id),))

